Documentation
¶
Index ¶
Constants ¶
const ( SourceLayerUnboundedIndex = -1 WhiteoutPrefix = ".wh." )
const (
MaxLandmark = 2
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ByPriority ¶
type ByPriority []*ConsolidatorEntry
func (ByPriority) Len ¶
func (b ByPriority) Len() int
func (ByPriority) Less ¶
func (b ByPriority) Less(i, j int) bool
func (ByPriority) Swap ¶
func (b ByPriority) Swap(i, j int)
type Consolidator ¶
type Consolidator struct {
Deltas []*Delta `json:"delta,omitempty"`
// Source starts from index 0
Source []*util.TraceableBlobDigest `json:"source,omitempty"`
Offsets []int64 `json:"offsets"`
// contains filtered or unexported fields
}
func NewConsolidator ¶
func NewConsolidator(ctx context.Context) *Consolidator
func (*Consolidator) AddDelta ¶
func (c *Consolidator) AddDelta(delta *Delta) error
AddDelta image to the pool of images, All the
func (*Consolidator) ExportTOC ¶
func (c *Consolidator) ExportTOC(w io.Writer, beautified bool) error
func (*Consolidator) GetOutputQueue ¶
func (c *Consolidator) GetOutputQueue() *[]*OutputEntry
func (*Consolidator) PopulateOffset ¶
func (c *Consolidator) PopulateOffset() error
type ConsolidatorEntry ¶
type ConsolidatorEntry struct {
// contains filtered or unexported fields
}
type Delta ¶
type Delta struct {
// DigestList references to actual layer storage
DigestList []*util.TraceableBlobDigest `json:"d,omitempty"`
// Pool stores the list of pointer to all the TOC entries
Pool [][]*util.TraceableEntry `json:"p,omitempty"`
// file queue
CheckPoint []int64
ImageName string `json:"in,omitempty"`
ImageTag string `json:"it,omitempty"`
Config string `json:"config"`
// contains filtered or unexported fields
}
func (*Delta) ExportTOC ¶
ExportTOC writes TOC for this image It must runs after the delta image has been consolidated (so that we have the correct offset point to the gzip chunks)
func (*Delta) OutputHeader ¶
OutputHeader writes compressed header for this delta image and returns the header size It must runs after the delta image has been consolidated (so that we have the correct offset point to the gzip chunks)
func (*Delta) PopulateOffset ¶
type OutputEntry ¶
type Overlay ¶
type Overlay struct {
// root is the root of the file system
Root *util.TraceableEntry `json:"-"`
// pool stores the list of pointer to all the TOC entries
EntryMap map[string]*util.TraceableEntry `json:"p,omitempty"`
// digest list (reference to actual layer storage)
// DigestList index range [0, n) where n is the total number of layers
// proxy.TraceableEntry's "source" int is starting from 1 which needs to subtract one to
// get the correct index
DigestList []*util.TraceableBlobDigest `json:"d,omitempty"`
ImageName string `json:"-"`
ImageTag string `json:"-"`
Config []byte `json:"-"`
// contains filtered or unexported fields
}
func LoadMergedImage ¶
func (*Overlay) AddImage ¶
AddImage overlays an entire image on top of what exists in the Overlay object.
func (*Overlay) AddLayer ¶
func (ov *Overlay) AddLayer(tb *util.TraceableBlobDigest) error
AddLayer overlays a single layer on top of what exists in the Overlay object.
func (*Overlay) SaveMergedImage ¶
Click to show internal directories.
Click to hide internal directories.